@@ -3,4 +3,6 @@ from pathlib import Path
 TESTS_FOLDER = Path(__file__).parent
 INPUT_DATA_FOLDER = TESTS_FOLDER / "input_data"
 RESPONSES_FOLDER = INPUT_DATA_FOLDER / "responses"
-INTRADAY_RESPONSES_FOLDER = RESPONSES_FOLDER / "intraday"
\ No newline at end of file
+INTRADAY_RESPONSES_FOLDER = RESPONSES_FOLDER / "intraday"
+GENERATED_PATH = TESTS_FOLDER / "generated"
+DOWNLOAD_INPUT_PATH = INPUT_DATA_FOLDER / "download"
\ No newline at end of file
